summaryrefslogtreecommitdiff
path: root/nuttx/configs/ea3131/include/board.h
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2011-05-27 15:26:52 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2011-05-27 15:26:52 +0000
commitbe85acd0f71ce088b4e1584e6ce485015288f63c (patch)
treec282e67081fdd2164b636f646cb75909d1bc137e /nuttx/configs/ea3131/include/board.h
parentcfc63f3cffcdcb89261c4bfc065d5591f5b6b561 (diff)
downloadpx4-nuttx-be85acd0f71ce088b4e1584e6ce485015288f63c.tar.gz
px4-nuttx-be85acd0f71ce088b4e1584e6ce485015288f63c.tar.bz2
px4-nuttx-be85acd0f71ce088b4e1584e6ce485015288f63c.zip
Rename all lpc313x to lpc31xx
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@3644 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/configs/ea3131/include/board.h')
-rwxr-xr-xnuttx/configs/ea3131/include/board.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/nuttx/configs/ea3131/include/board.h b/nuttx/configs/ea3131/include/board.h
index 464099107..7e0a01b6a 100755
--- a/nuttx/configs/ea3131/include/board.h
+++ b/nuttx/configs/ea3131/include/board.h
@@ -44,7 +44,7 @@
#include <nuttx/config.h>
#ifndef __ASSEMBLY__
# include <stdint.h>
-# include "lpc313x_cgudrvr.h"
+# include "lpc31_cgudrvr.h"
#endif
/************************************************************************************
@@ -131,16 +131,16 @@ extern "C" {
* Public Function Prototypes
************************************************************************************/
/************************************************************************************
- * Name: lpc313x_boardinitialize
+ * Name: lpc31_boardinitialize
*
* Description:
* All LPC313X architectures must provide the following entry point. This entry
* point is called early in the intitialization -- after all memory has been
* configured and mapped but before any devices have been initialized.
*
************************************************************************************/
-EXTERN void lpc313x_boardinitialize(void);
+EXTERN void lpc31_boardinitialize(void);
/************************************************************************************
* Button support.
@@ -131,16 +131,16 @@ extern "C" {
*
* Description:
- * All LPC313X architectures must provide the following entry point. This entry
+ * All LPC31XX architectures must provide the following entry point. This entry
* point is called early in the intitialization -- after all memory has been
* configured and mapped but before any devices have been initialized.